@@ -1,5 +1,5 @@
 use binrw::{
-    derive_binread,
+    binread,
     io::{Cursor, Seek, SeekFrom},
     BinRead,
 };
@@ -39,7 +39,7 @@ fn enum_non_copy_args() {
 
 #[test]
 fn enum_calc_temp_field() {
-    #[derive_binread]
+    #[binread]
     #[derive(Debug, Eq, PartialEq)]
     enum Test {
         #[br(magic(0u8))]
@@ -111,6 +111,7 @@ fn enum_return_all_errors() {
     }
 
     let error = Test::read(&mut Cursor::new("\0\x01")).expect_err("accepted bad data");
+    dbg!(&error);
     match error {
         binrw::Error::EnumErrors {
             pos,
@@ -126,7 +127,10 @@ fn enum_return_all_errors() {
                 panic!("expected BadMagic; got {:?}", variant_errors[0].1);
             }
             assert_eq!(variant_errors[1].0, "Two");
-            assert!(matches!(variant_errors[1].1, binrw::Error::Io(..)));
+            assert!(matches!(
+                variant_errors[1].1.root_cause(),
+                binrw::Error::Io(..)
+            ));
         }
         _ => panic!("wrong error type"),
     }
